pub enum StopDecision {
Continue,
EarlyAccept {
posterior: f64,
},
EarlyReject {
posterior: f64,
},
}Expand description
Decision returned by StopRule::evaluate.
Variants
Continue
Continue dispatching strategies.
EarlyAccept
Posterior is high enough that even worst-case remaining evidence cannot drop it below the confirm threshold. Endpoint existence is confirmed.
EarlyReject
Posterior is low enough that even best-case remaining evidence cannot raise it above the likely threshold. Endpoint non-existence is confirmed.