pub struct StopRule { /* private fields */ }Expand description
Evaluates evidence against early-stop thresholds.
confirm_threshold = logit(0.80); any accumulated log-odds that can no longer fall below this
value triggers EarlyAccept. likely_threshold = logit(0.60); any accumulated log-odds that
can no longer rise above this value triggers EarlyReject.
Implementations
Sourceimpl StopRule
impl StopRule
Sourcepub fn evaluate(
&self,
accumulator: &EvidenceAccumulator,
remaining: &[StrategyMetaForStop],
) -> StopDecision
pub fn evaluate( &self, accumulator: &EvidenceAccumulator, remaining: &[StrategyMetaForStop], ) -> StopDecision
Evaluates whether to continue, accept early, or reject early.
- If
log_odds - max_negative_remaining >= confirm_threshold→EarlyAccept. - Else if
log_odds + max_positive_remaining < likely_threshold→EarlyReject. - Otherwise →
Continue.